@@ -3,8 +3,10 @@ use crate::database::Database;
 use crate::model::BlockHeight;
 use crate::state::Error;
 
-const CHAIN_NAME_KEY: &[u8] = b"chain_name";
-const START_HEIGHT_KEY: &[u8] = b"chain_height";
+pub(crate) const CHAIN_NAME_KEY: &[u8] = b"chain_name";
+pub(crate) const CHAIN_HEIGHT_KEY: &[u8] = b"chain_height";
+pub(crate) const FINALIZED_DA_HEIGHT: &[u8] = b"finalized_da_height";
+pub(crate) const VALIDATORS_DA_HEIGHT: &[u8] = b"current_validator_set";
 
 impl Database {
     pub fn init_chain_name(&self, name: String) -> Result<(), Error> {
@@ -22,7 +24,7 @@ impl Database {
     }
 
     pub fn init_chain_height(&self, height: BlockHeight) -> Result<(), Error> {
-        self.insert(START_HEIGHT_KEY, METADATA, height)
+        self.insert(CHAIN_HEIGHT_KEY, METADATA, height)
             .and_then(|v| {
                 if v.is_some() {
                     Err(Error::ChainAlreadyInitialized)
@@ -33,6 +35,6 @@ impl Database {
     }
 
     pub fn get_starting_chain_height(&self) -> Result<Option<BlockHeight>, Error> {
-        self.get(START_HEIGHT_KEY, METADATA)
+        self.get(CHAIN_HEIGHT_KEY, METADATA)
     }
 }
